| Title: | Alternative Continuous and Discrete Distributions |
|---|---|
| Description: | The aim is to develop an R package, which is the 'new.dist' package, for the probability (density) function, the distribution function, the quantile function and the associated random number generation function for discrete and continuous distributions, which have recently been proposed in the literature. This package implements the following distributions: The Power Muth Distribution, a Bimodal Weibull Distribution, the Discrete Lindley Distribution, The Gamma-Lomax Distribution, Weighted Geometric Distribution, a Power Log-Dagum Distribution, Kumaraswamy Distribution, Lindley Distribution, the Unit-Inverse Gaussian Distribution, EP Distribution, Akash Distribution, Ishita Distribution, Maxwell Distribution, the Standard Omega Distribution, Slashed Generalized Rayleigh Distribution, Two-Parameter Rayleigh Distribution, Muth Distribution, Uniform-Geometric Distribution, Discrete Weibull Distribution. |
| Authors: | Ramazan Akman [cre, ctb] (https://www.researchgate.net/profile/Ramazan-Akman), Coşkun Kuş [aut, ctb] (https://www.selcuk.edu.tr/Person/Detail/coskun), Ihab Abusaif [aut, ctb] (https://www.researchgate.net/profile/Ihab-Abusaif) |
| Maintainer: | Ramazan Akman <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-05-25 10:53:35 UTC |
| Source: | https://github.com/akmn35/new.dist |
Density, distribution function, quantile function and random generation for
a Bimodal Weibull distribution with parameters shape and scale.
dbwd(x, alpha, beta = 1, sigma, log = FALSE) pbwd(q, alpha, beta = 1, sigma, lower.tail = TRUE, log.p = FALSE) qbwd(p, alpha, beta = 1, sigma, lower.tail = TRUE) rbwd(n, alpha, beta = 1, sigma)dbwd(x, alpha, beta = 1, sigma, log = FALSE) pbwd(q, alpha, beta = 1, sigma, lower.tail = TRUE, log.p = FALSE) qbwd(p, alpha, beta = 1, sigma, lower.tail = TRUE) rbwd(n, alpha, beta = 1, sigma)
x, q
|
vector of quantiles. |
alpha |
a shape parameter. |
beta |
a scale parameter. |
sigma |
a control parameter that controls the uni- or bimodality of the distribution. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
A Bimodal Weibull distribution with shape parameter ,
scale parameter ,and the control parameter
that determines the uni- or bimodality of the
distribution, has density
where
and
dbwd gives the density, pbwd gives the distribution
function, qbwd gives the quantile function and rbwd generates
random deviates.
Vila, R. ve Niyazi Çankaya, M., 2022, A bimodal Weibull distribution: properties and inference, Journal of Applied Statistics, 49 (12), 3044-3062.
library(new.dist) dbwd(1,alpha=2,beta=3,sigma=4) pbwd(1,alpha=2,beta=3,sigma=4) qbwd(.7,alpha=2,beta=3,sigma=4) rbwd(10,alpha=2,beta=3,sigma=4)library(new.dist) dbwd(1,alpha=2,beta=3,sigma=4) pbwd(1,alpha=2,beta=3,sigma=4) qbwd(.7,alpha=2,beta=3,sigma=4) rbwd(10,alpha=2,beta=3,sigma=4)
Density, distribution function, quantile function and random generation for the discrete Lindley distribution.
ddLd1(x, theta, log = FALSE) pdLd1(q, theta, lower.tail = TRUE, log.p = FALSE) qdLd1(p, theta, lower.tail = TRUE) rdLd1(n, theta)ddLd1(x, theta, log = FALSE) pdLd1(q, theta, lower.tail = TRUE, log.p = FALSE) qdLd1(p, theta, lower.tail = TRUE) rdLd1(n, theta)
x, q
|
vector of quantiles. |
theta |
a parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Discrete Lindley distribution with a parameter , has density
where
ddLd1 gives the density, pdLd1 gives the distribution
function, qdLd1 gives the quantile function and rdLd1 generates
random deviates.
Gómez-Déniz, E. ve Calderín-Ojeda, E., 2011, The discrete Lindley distribution: properties and applications.Journal of statistical computation and simulation, 81 (11), 1405-1416.
library(new.dist) ddLd1(1,theta=2) pdLd1(2,theta=1) qdLd1(.993,theta=2) rdLd1(10,theta=1)library(new.dist) ddLd1(1,theta=2) pdLd1(2,theta=1) qdLd1(.993,theta=2) rdLd1(10,theta=1)
Density, distribution function, quantile function and random generation for the discrete Lindley distribution.
ddLd2(x, theta, log = FALSE) pdLd2(q, theta, lower.tail = TRUE, log.p = FALSE) qdLd2(p, theta, lower.tail = TRUE) rdLd2(n, theta)ddLd2(x, theta, log = FALSE) pdLd2(q, theta, lower.tail = TRUE, log.p = FALSE) qdLd2(p, theta, lower.tail = TRUE) rdLd2(n, theta)
x, q
|
vector of quantiles. |
theta |
a parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
the discrete Lindley distribution with a parameter ,
has density
where
ddLd2 gives the density, pdLd2 gives the distribution
function, qdLd2 gives the quantile function and rdLd2 generates
random deviates.
Bakouch, H. S., Jazi, M. A. ve Nadarajah, S., 2014, A new discrete distribution, Statistics, 48 (1), 200-240.
library(new.dist) ddLd2(2,theta=2) pdLd2(1,theta=2) qdLd2(.5,theta=2) rdLd2(10,theta=1)library(new.dist) ddLd2(2,theta=2) pdLd2(1,theta=2) qdLd2(.5,theta=2) rdLd2(10,theta=1)
Density, distribution function, quantile function and random generation for the EP distribution.
dEPd(x, lambda, beta, log = FALSE) pEPd(q, lambda, beta, lower.tail = TRUE, log.p = FALSE) qEPd(p, lambda, beta, lower.tail = TRUE) rEPd(n, lambda, beta)dEPd(x, lambda, beta, log = FALSE) pEPd(q, lambda, beta, lower.tail = TRUE, log.p = FALSE) qEPd(p, lambda, beta, lower.tail = TRUE) rEPd(n, lambda, beta)
x, q
|
vector of quantiles. |
lambda, beta
|
are parameters. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The EP distribution with parameters and ,
has density
where
dEPd gives the density, pEPd gives the distribution
function, qEPd gives the quantile function and rEPd generates
random deviates.
Kuş, C., 2007, A new lifetime distribution, Computational Statistics & Data Analysis, 51 (9), 4497-4509.
library(new.dist) dEPd(1, lambda=2, beta=3) pEPd(1,lambda=2,beta=3) qEPd(.8,lambda=2,beta=3) rEPd(10,lambda=2,beta=3)library(new.dist) dEPd(1, lambda=2, beta=3) pEPd(1,lambda=2,beta=3) qEPd(.8,lambda=2,beta=3) rEPd(10,lambda=2,beta=3)
Density, distribution function, quantile function and random generation for
the gamma-Lomax distribution with parameters shapes and scale.
dgld(x, a, alpha, beta = 1, log = FALSE) pgld(q, a, alpha, beta = 1, lower.tail = TRUE, log.p = FALSE) qgld(p, a, alpha, beta = 1, lower.tail = TRUE) rgld(n, a, alpha, beta = 1)dgld(x, a, alpha, beta = 1, log = FALSE) pgld(q, a, alpha, beta = 1, lower.tail = TRUE, log.p = FALSE) qgld(p, a, alpha, beta = 1, lower.tail = TRUE) rgld(n, a, alpha, beta = 1)
x, q
|
vector of quantiles. |
a, alpha
|
are shape parameters. |
beta |
a scale parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Gamma-Lomax distribution shape parameters
and , and scale parameter is ,
has density
where
dgld gives the density, pgld gives the distribution
function, qgld gives the quantile function and rgld generates
random deviates.
Cordeiro, G. M., Ortega, E. M. ve Popović, B. V., 2015, The gamma-Lomax distribution, Journal of statistical computation and simulation, 85 (2), 305-319.
Ristić, M. M., & Balakrishnan, N. (2012), The gamma-exponentiated exponential distribution. Journal of statistical computation and simulation , 82(8), 1191-1206.
library(new.dist) dgld(1, a=2, alpha=3, beta=4) pgld(1, a=2,alpha=3,beta=4) qgld(.8, a=2,alpha=3,beta=4) rgld(10, a=2,alpha=3,beta=4)library(new.dist) dgld(1, a=2, alpha=3, beta=4) pgld(1, a=2,alpha=3,beta=4) qgld(.8, a=2,alpha=3,beta=4) rgld(10, a=2,alpha=3,beta=4)
Density, distribution function, quantile function and random generation for
Kumaraswamy distribution with shape parameters.
dkd(x, lambda, alpha, log = FALSE) pkd(q, lambda, alpha, lower.tail = TRUE, log.p = FALSE) qkd(p, lambda, alpha, lower.tail = TRUE) rkd(n, lambda, alpha)dkd(x, lambda, alpha, log = FALSE) pkd(q, lambda, alpha, lower.tail = TRUE, log.p = FALSE) qkd(p, lambda, alpha, lower.tail = TRUE) rkd(n, lambda, alpha)
x, q
|
vector of quantiles. |
alpha, lambda
|
are non-negative shape parameters. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
Kumaraswamy distribution with non-negative shape
parameters and has density
where
dkd gives the density, pkd gives the distribution
function, qkd gives the quantile function and rkd generates
random deviates.
Kohansal, A. ve Bakouch, H. S., 2021, Estimation procedures for Kumaraswamy distribution parameters under adaptive type-II hybrid progressive censoring, Communications in Statistics-Simulation and Computation, 50 (12), 4059-4078.
library("new.dist") dkd(0.1,lambda=2,alpha=3) pkd(0.5,lambda=2,alpha=3) qkd(.8,lambda=2,alpha=3) rkd(10,lambda=2,alpha=3)library("new.dist") dkd(0.1,lambda=2,alpha=3) pkd(0.5,lambda=2,alpha=3) qkd(.8,lambda=2,alpha=3) rkd(10,lambda=2,alpha=3)
Density, distribution function, quantile function and random generation for the Lindley distribution.
dLd(x, theta, log = FALSE) pLd(q, theta, lower.tail = TRUE, log.p = FALSE) qLd(p, theta, lower.tail = TRUE) rLd(n, theta)dLd(x, theta, log = FALSE) pLd(q, theta, lower.tail = TRUE, log.p = FALSE) qLd(p, theta, lower.tail = TRUE) rLd(n, theta)
x, q
|
vector of quantiles. |
theta |
a parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Lindley distribution with a parameter , has density
where
dLd gives the density, pLd gives the distribution
function, qLd gives the quantile function and rLd generates
random deviates.
Akgül, F. G., Acıtaş, Ş. ve Şenoğlu, B., 2018, Inferences on stress–strength reliability based on ranked set sampling data in case of Lindley distribution, Journal of statistical computation and simulation, 88 (15), 3018-3032.
library(new.dist) dLd(1,theta=2) pLd(1,theta=2) qLd(.8,theta=1) rLd(10,theta=1)library(new.dist) dLd(1,theta=2) pLd(1,theta=2) qLd(.8,theta=1) rLd(10,theta=1)
Density, distribution function, quantile function and random generation for
Maxwell distribution with parameter scale.
dmd(x, theta = 1, log = FALSE) pmd(q, theta = 1, lower.tail = TRUE, log.p = FALSE) qmd(p, theta = 1, lower.tail = TRUE) rmd(n, theta = 1)dmd(x, theta = 1, log = FALSE) pmd(q, theta = 1, lower.tail = TRUE, log.p = FALSE) qmd(p, theta = 1, lower.tail = TRUE) rmd(n, theta = 1)
x, q
|
vector of quantiles. |
theta |
a scale parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
Maxwell distribution with scale parameter ,
has density
where
dmd gives the density, pmd gives the distribution
function, qmd gives the quantile function and rmd generates
random deviates.
Krishna, H., Vivekanand ve Kumar, K., 2015, Estimation in Maxwell distribution with randomly censored data, Journal of statistical computation and simulation, 85 (17), 3560-3578.
library(new.dist) dmd(1,theta=2) pmd(1,theta=2) qmd(.4,theta=5) rmd(10,theta=1)library(new.dist) dmd(1,theta=2) pmd(1,theta=2) qmd(.4,theta=5) rmd(10,theta=1)
Density, distribution function, quantile function and random generation for on the Muth distribution.
domd(x, alpha, log = FALSE) pomd(q, alpha, lower.tail = TRUE, log.p = FALSE) qomd(p, alpha, lower.tail = TRUE) romd(n, alpha)domd(x, alpha, log = FALSE) pomd(q, alpha, lower.tail = TRUE, log.p = FALSE) qomd(p, alpha, lower.tail = TRUE) romd(n, alpha)
x, q
|
vector of quantiles. |
alpha |
a parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Muth distribution with a parameter , has
density
where
domd gives the density, pomd gives the distribution
function, qomd gives the quantile function and romd generates
random deviates.
Jodrá, P., Jiménez-Gamero, M. D. ve Alba-Fernández, M. V., 2015, On the Muth distribution, Mathematical Modelling and Analysis, 20 (3), 291-310.
library(new.dist) domd(1,alpha=.2) pomd(1,alpha=.2) qomd(.8,alpha=.1) romd(10,alpha=1)library(new.dist) domd(1,alpha=.2) pomd(1,alpha=.2) qomd(.8,alpha=.1) romd(10,alpha=1)
Density, distribution function, quantile function and random generation for a Power Log Dagum distribution.
dpldd(x, alpha, beta, theta, log = FALSE) ppldd(q, alpha, beta, theta, lower.tail = TRUE, log.p = FALSE) qpldd(p, alpha, beta, theta, lower.tail = TRUE) rpldd(n, alpha, beta, theta)dpldd(x, alpha, beta, theta, log = FALSE) ppldd(q, alpha, beta, theta, lower.tail = TRUE, log.p = FALSE) qpldd(p, alpha, beta, theta, lower.tail = TRUE) rpldd(n, alpha, beta, theta)
x, q
|
vector of quantiles. |
alpha, beta, theta
|
are parameters. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
A Power Log Dagum Distribution with parameters , and
, has density
where
dpldd gives the density, ppldd gives the distribution
function, qpldd gives the quantile function and rpldd generates
random deviates.
The distributions hazard function
Bakouch, H. S., Khan, M. N., Hussain, T. ve Chesneau, C., 2019, A power log-Dagum distribution: estimation and applications, Journal of Applied Statistics, 46 (5), 874-892.
library(new.dist) dpldd(1, alpha=2, beta=3, theta=4) ppldd(1,alpha=2,beta=3,theta=4) qpldd(.8,alpha=2,beta=3,theta=4) rpldd(10,alpha=2,beta=3,theta=4)library(new.dist) dpldd(1, alpha=2, beta=3, theta=4) ppldd(1,alpha=2,beta=3,theta=4) qpldd(.8,alpha=2,beta=3,theta=4) rpldd(10,alpha=2,beta=3,theta=4)
Density, distribution function, quantile function and random generation for
a Ram Awadh distribution with parameter scale.
dRA(x, theta = 1, log = FALSE) pRA(q, theta = 1, lower.tail = TRUE, log.p = FALSE) qRA(p, theta = 1, lower.tail = TRUE) rRA(n, theta = 1)dRA(x, theta = 1, log = FALSE) pRA(q, theta = 1, lower.tail = TRUE, log.p = FALSE) qRA(p, theta = 1, lower.tail = TRUE) rRA(n, theta = 1)
x, q
|
vector of quantiles. |
theta |
a scale parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
Ram Awadh distribution with scale parameter
, has density
where
dRA gives the density, pRA gives the distribution
function, qRA gives the quantile function and rRA
generates random deviates.
Shukla, K. K., Shanker, R. ve Tiwari, M. K., 2022, A new one parameter discrete distribution and its applications, Journal of Statistics and Management Systems, 25 (1), 269-283.
library(new.dist) dRA(1,theta=2) pRA(1,theta=2) qRA(.1,theta=1) rRA(10,theta=1)library(new.dist) dRA(1,theta=2) pRA(1,theta=2) qRA(.1,theta=1) rRA(10,theta=1)
Density, distribution function, quantile function and random generation for
the Slashed generalized Rayleigh distribution with parameters shape,
scale and kurtosis.
dsgrd(x, theta, alpha, beta, log = FALSE) psgrd(q, theta, alpha, beta, lower.tail = TRUE, log.p = FALSE) qsgrd(p, theta, alpha, beta, lower.tail = TRUE) rsgrd(n, theta, alpha, beta)dsgrd(x, theta, alpha, beta, log = FALSE) psgrd(q, theta, alpha, beta, lower.tail = TRUE, log.p = FALSE) qsgrd(p, theta, alpha, beta, lower.tail = TRUE) rsgrd(n, theta, alpha, beta)
x, q
|
vector of quantiles. |
theta |
a scale parameter. |
alpha |
a shape parameter. |
beta |
a kurtosis parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Slashed Generalized Rayleigh distribution with shape parameter
, scale parameter and kurtosis
parameter , has density
where F(.;a,b) is the cdf of the Gamma (a,b) distribution, and
dsgrd gives the density, psgrd gives the distribution
function, qsgrd gives the quantile function and rsgrd generates
random deviates.
Iriarte, Y. A., Vilca, F., Varela, H. ve Gómez, H. W., 2017, Slashed generalized Rayleigh distribution, Communications in Statistics- Theory and Methods, 46 (10), 4686-4699.
library(new.dist) dsgrd(2,theta=3,alpha=1,beta=4) psgrd(5,theta=3,alpha=1,beta=4) qsgrd(.4,theta=3,alpha=1,beta=4) rsgrd(10,theta=3,alpha=1,beta=4)library(new.dist) dsgrd(2,theta=3,alpha=1,beta=4) psgrd(5,theta=3,alpha=1,beta=4) qsgrd(.4,theta=3,alpha=1,beta=4) rsgrd(10,theta=3,alpha=1,beta=4)
Density, distribution function, quantile function and random generation for the Standard Omega distribution.
dsod(x, alpha, beta, log = FALSE) psod(q, alpha, beta, lower.tail = TRUE, log.p = FALSE) qsod(p, alpha, beta, lower.tail = TRUE) rsod(n, alpha, beta)dsod(x, alpha, beta, log = FALSE) psod(q, alpha, beta, lower.tail = TRUE, log.p = FALSE) qsod(p, alpha, beta, lower.tail = TRUE) rsod(n, alpha, beta)
x, q
|
vector of quantiles. |
alpha, beta
|
are parameters. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Standard Omega distribution with parameters
and , has density
where
dsod gives the density, psod gives the distribution
function, qsod gives the quantile function and rsod generates
random deviates.
Birbiçer, İ. ve Genç, A. İ., 2022, On parameter estimation of the standard omega distribution. Journal of Applied Statistics, 1-17.
library(new.dist) dsod(0.4, alpha=1, beta=2) psod(0.4, alpha=1, beta=2) qsod(.8, alpha=1, beta=2) rsod(10, alpha=1, beta=2)library(new.dist) dsod(0.4, alpha=1, beta=2) psod(0.4, alpha=1, beta=2) qsod(.8, alpha=1, beta=2) rsod(10, alpha=1, beta=2)
Density, distribution function, quantile function and random generation for
the Power Muth distribution with parameters shape and scale.
dtpmd(x, beta = 1, alpha, log = FALSE) ptpmd(q, beta = 1, alpha, lower.tail = TRUE, log.p = FALSE) qtpmd(p, beta = 1, alpha, lower.tail = TRUE) rtpmd(n, beta = 1, alpha)dtpmd(x, beta = 1, alpha, log = FALSE) ptpmd(q, beta = 1, alpha, lower.tail = TRUE, log.p = FALSE) qtpmd(p, beta = 1, alpha, lower.tail = TRUE) rtpmd(n, beta = 1, alpha)
x, q
|
vector of quantiles. |
beta |
a scale parameter. |
alpha |
a shape parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Power Muth distribution with shape parameter and
scale parameter has density
where
dtpmd gives the density, ptpmd gives the distribution
function, qtpmd gives the quantile function and rtpmd generates
random deviates.
Hazard function;
Jodra, P., Gomez, H. W., Jimenez-Gamero, M. D., & Alba-Fernandez, M. V. (2017). The power Muth distribution . Mathematical Modelling and Analysis, 22(2), 186-201.
library(new.dist) dtpmd(1, beta=2, alpha=3) ptpmd(1,beta=2,alpha=3) qtpmd(.5,beta=2,alpha=3) rtpmd(10,beta=2,alpha=3)library(new.dist) dtpmd(1, beta=2, alpha=3) ptpmd(1,beta=2,alpha=3) qtpmd(.5,beta=2,alpha=3) rtpmd(10,beta=2,alpha=3)
Density, distribution function, quantile function and random generation
for the Two-Parameter Rayleigh distribution with parameters location
and scale.
dtprd(x, lambda = 1, mu, log = FALSE) ptprd(q, lambda = 1, mu, lower.tail = TRUE, log.p = FALSE) qtprd(p, lambda = 1, mu, lower.tail = TRUE) rtprd(n, lambda = 1, mu)dtprd(x, lambda = 1, mu, log = FALSE) ptprd(q, lambda = 1, mu, lower.tail = TRUE, log.p = FALSE) qtprd(p, lambda = 1, mu, lower.tail = TRUE) rtprd(n, lambda = 1, mu)
x, q
|
vector of quantiles. |
lambda |
a scale parameter. |
mu |
a location parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Two-Parameter Rayleigh distribution with scale parameter
and location parameter , has density
where
dtprd gives the density, ptprd gives the distribution
function, qtprd gives the quantile function and rtprd generates
random deviates.
Dey, S., Dey, T. ve Kundu, D., 2014, Two-parameter Rayleigh distribution: different methods of estimation, American Journal of Mathematical and Management Sciences, 33 (1), 55-74.
library(new.dist) dtprd(5, lambda=4, mu=4) ptprd(2,lambda=2,mu=1) qtprd(.5,lambda=2,mu=1) rtprd(10,lambda=2,mu=1)library(new.dist) dtprd(5, lambda=4, mu=4) ptprd(2,lambda=2,mu=1) qtprd(.5,lambda=2,mu=1) rtprd(10,lambda=2,mu=1)
Density, distribution function, quantile function and random generation for the Uniform-Geometric distribution.
dugd(x, theta, log = FALSE) pugd(q, theta, lower.tail = TRUE, log.p = FALSE) qugd(p, theta, lower.tail = TRUE) rugd(n, theta)dugd(x, theta, log = FALSE) pugd(q, theta, lower.tail = TRUE, log.p = FALSE) qugd(p, theta, lower.tail = TRUE) rugd(n, theta)
x, q
|
vector of quantiles. |
theta |
a parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Uniform-Geometric distribution with shape parameter , has
density
where
and
dugd gives the density, pugd gives the distribution
function, qugd gives the quantile function and rugd generates
random deviates.
Akdoğan, Y., Kuş, C., Asgharzadeh, A., Kınacı, İ., & Sharafi, F. (2016). Uniform-geometric distribution. Journal of Statistical Computation and Simulation, 86(9), 1754-1770.
library(new.dist) dugd(1, theta=0.5) pugd(1,theta=.5) qugd(0.6,theta=.1) rugd(10,theta=.1)library(new.dist) dugd(1, theta=0.5) pugd(1,theta=.5) qugd(0.6,theta=.1) rugd(10,theta=.1)
Density, distribution function, quantile function and random generation for
the Unit Inverse Gaussian distribution mean and scale.
duigd(x, mu, lambda = 1, log = FALSE) puigd(q, mu, lambda = 1, lower.tail = TRUE, log.p = FALSE) quigd(p, mu, lambda = 1, lower.tail = TRUE) ruigd(n, mu, lambda = 1)duigd(x, mu, lambda = 1, log = FALSE) puigd(q, mu, lambda = 1, lower.tail = TRUE, log.p = FALSE) quigd(p, mu, lambda = 1, lower.tail = TRUE) ruigd(n, mu, lambda = 1)
x, q
|
vector of quantiles. |
mu |
a mean parameter. |
lambda |
a scale parameter. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Unit Inverse Gaussian distribution scale
parameter and mean
parameter , has density
where
duigd gives the density, puigd gives the distribution
function, quigd gives the quantile function and ruigd generates
random deviates.
Ghitany, M., Mazucheli, J., Menezes, A. ve Alqallaf, F., 2019, The unit-inverse Gaussian distribution: A new alternative to two-parameter distributions on the unit interval, Communications in Statistics-Theory and Methods, 48 (14), 3423-3438.
library(new.dist) duigd(1, mu=2, lambda=3) puigd(1,mu=2,lambda=3) quigd(.1,mu=2,lambda=3) ruigd(10,mu=2,lambda=3)library(new.dist) duigd(1, mu=2, lambda=3) puigd(1,mu=2,lambda=3) quigd(.1,mu=2,lambda=3) ruigd(10,mu=2,lambda=3)
Density, distribution function, quantile function and random generation for the Weighted Geometric distribution.
dwgd(x, alpha, lambda, log = FALSE) pwgd(q, alpha, lambda, lower.tail = TRUE, log.p = FALSE) qwgd(p, alpha, lambda, lower.tail = TRUE) rwgd(n, alpha, lambda)dwgd(x, alpha, lambda, log = FALSE) pwgd(q, alpha, lambda, lower.tail = TRUE, log.p = FALSE) qwgd(p, alpha, lambda, lower.tail = TRUE) rwgd(n, alpha, lambda)
x, q
|
vector of quantiles. |
alpha, lambda
|
are parameters. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are
|
p |
vector of probabilities. |
n |
number of observations. If |
The Weighted Geometric distribution with parameters and
, has density
where
dwgd gives the density, pwgd gives the distribution
function, qwgd gives the quantile function and rwgd generates
random deviates.
Najarzadegan, H., Alamatsaz, M. H., Kazemi, I. ve Kundu, D., 2020, Weighted bivariate geometric distribution: Simulation and estimation, Communications in Statistics-Simulation and Computation, 49 (9), 2419-2443.
library(new.dist) dwgd(1,alpha=.2,lambda=3) pwgd(1,alpha=.2,lambda=3) qwgd(.98,alpha=.2,lambda=3) rwgd(10,alpha=.2,lambda=3)library(new.dist) dwgd(1,alpha=.2,lambda=3) pwgd(1,alpha=.2,lambda=3) qwgd(.98,alpha=.2,lambda=3) rwgd(10,alpha=.2,lambda=3)